#!/bin/bash
#SBATCH --partition=slim16 		# (queue, see sinfo) 
#SBATCH --ntasks=16			# number of threads
#SBATCH --mem 128G 			#memory pool for all cores 
#SBATCH -o slurm.%u.%j.out 		#STDOUT 
#SBATCH -e slurm.%u.%j.err 		#STDERR

module load ngs/minimap2/2.10 
module load ngs/samtools/1.8


#Set variables

BAM_FILE=${MINIMAP2_ALIGNMENT_FOLDER}/${READS%.fq.gz}_to_${GENOME_INDEX%.mmi}.bam
SORTED_BAM_FILE=${BAM_FILE%.bam}.sorted.bam

# Map error-corrected reads with mmp2 to the genome index
	# The "--MD" is to be able to run Sniffles based on this discussion: https://github.com/lh3/minimap2/issues/142

minimap2 -t 16 --MD -a ${MINIMAP2_INDEX_FOLDER}/${GENOME_INDEX} ${READS_FOLDER}/${READS} | samtools view -bh > ${BAM_FILE}

# Sort and index bam file

samtools sort \
	-@ 16 \
	-o ${SORTED_BAM_FILE} \
	${BAM_FILE} && \
samtools index ${SORTED_BAM_FILE}

# Filter by mapping quality and remove reads unmapped, not primary alignment and supplementary alignment

samtools view \
	-@ 16 \
	-q 10 \
	-F 2308 \
	-b \
	${SORTED_BAM_FILE} \
	> ${SORTED_BAM_FILE%.sorted.bam}.sorted.mapq10.F2308.bam &&
samtools index ${SORTED_BAM_FILE%.sorted.bam}.sorted.mapq10.F2308.bam


## clean up

rm ${BAM_FILE}


